<!-- Thanks for helping us improve tweedledum! -->

### Description
<!-- Include relevant issues here, describe what changed and why -->

### Suggested changelog entry:
<!-- Fill in the below block with the expected RestructuredText entry.
     Delete if no entry needed; -->

```rst

```

<!-- If the upgrade guide needs updating, note that here too -->
